"""URL configurations for mail"""
from django.conf import settings
from django.conf.urls import url

from mitol.mail.views import EmailDebuggerView

urlpatterns = []

if getattr(settings, "MITOL_MAIL_ENABLE_EMAIL_DEBUGGER", False):  # pragma: no cover
    urlpatterns += [
        url(r"^__emaildebugger__/$", EmailDebuggerView.as_view(), name="email-debugger")
    ]



"""Mail views"""
from django.shortcuts import render
from django.utils.decorators import method_decorator
from django.views import View
from django.views.decorators.csrf import csrf_exempt

from mitol.mail.api import get_message_classes
from mitol.mail.forms import EmailDebuggerForm


@method_decorator(csrf_exempt, name="dispatch")
class EmailDebuggerView(View):
    """Email debugger view"""

    form_cls = EmailDebuggerForm
    template_name = "mail/email_debugger.html"

    def get(self, request):
        """Displays the debugger UI"""
        form = self.form_cls(initial={})
        return render(request, self.template_name, {"form": form})

    def post(self, request):  # pragma: no cover
        """Renders a test email"""
        form = self.form_cls(request.POST)

        if not form.is_valid():
            return render(request, self.template_name, {"form": form})

        template_name = form.cleaned_data["template_name"]

        # if the form was valid, this should match on a message class
        for message_cls in get_message_classes():
            if message_cls.template_name == template_name:
                instance = message_cls.debug()

        return render(
            request,
            self.template_name,
            {
                "form": form,
                "subject": instance.subject,
                "html_body": instance.alternatives[0][0],
                "text_body": instance.body,
            },
        )



"""
Email settings for django builtin email functionality

Note: this does not cover anymail, mailgun, etc configuration.
Those are covered by the mitol-django-mail app.
"""

from mitol.common.envs import app_namespaced, get_bool, get_int, get_string

MAILGUN_RECIPIENT_OVERRIDE = get_string(
    name="MAILGUN_RECIPIENT_OVERRIDE",
    default=None,
    dev_only=True,
    description="Override the recipient for outgoing email, development only",
)
EMAIL_RECIPIENT_OVERRIDE = get_string(
    name="EMAIL_RECIPIENT_OVERRIDE",
    default=MAILGUN_RECIPIENT_OVERRIDE,
    dev_only=True,
    description="Override the recipient for outgoing email, development only",
)
EMAIL_BACKEND = get_string(
    name=app_namespaced("EMAIL_BACKEND"),
    default="django.core.mail.backends.smtp.EmailBackend",
    description="The default email backend to use for outgoing email. This is used in some places by django itself. See `NOTIFICATION_EMAIL_BACKEND` for the backend used for most application emails.",
)
EMAIL_HOST = get_string(
    name=app_namespaced("EMAIL_HOST"),
    default="localhost",
    description="Outgoing e-mail hostname",
)
EMAIL_PORT = get_int(
    name=app_namespaced("EMAIL_PORT"), default=25, description="Outgoing e-mail port"
)
EMAIL_HOST_USER = get_string(
    name=app_namespaced("EMAIL_USER"),
    default="",
    description="Outgoing e-mail auth username",
)
EMAIL_HOST_PASSWORD = get_string(
    name=app_namespaced("EMAIL_PASSWORD"),
    default="",
    description="Outgoing e-mail auth password",
)
EMAIL_USE_TLS = get_bool(
    name=app_namespaced("EMAIL_TLS"),
    default=False,
    description="Outgoing e-mail TLS setting",
)
EMAIL_SUPPORT = get_string(
    name=app_namespaced("SUPPORT_EMAIL"),
    default=EMAIL_RECIPIENT_OVERRIDE or "support@localhost",
    description="Email address listed for customer support",
)
DEFAULT_FROM_EMAIL = get_string(
    name=app_namespaced("FROM_EMAIL"),
    default="webmaster@localhost",
    description="E-mail to use for the from field",
)




# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/mitol/mail:mitol-django-mail

from setuptools import setup

setup(**{
    'authors': [
        'MIT Office of Open Learning <mitx-devops@mit.edu>',
    ],
    'classifiers': [
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    'description': 'MIT Open Learning django app extensions for mail',
    'license': 'BSD 3-Clause License',
    'name': 'mitol-django-mail',
    'version': '3.0.0',
    'zip_safe': True,
    'package_dir': {
        '': 'src',
    },
    'packages': (
        'mitol',
        'mitol.mail',
        'mitol.mail.settings',
    ),
    'namespace_packages': (
        'mitol',
    ),
    'package_data': {
        'mitol.mail': (
            'CHANGELOG.md',
            'README.md',
            'py.typed',
            'templates/mail/email_base.html',
            'templates/mail/email_debugger.html',
            'templates/mail/partials/_logo.html',
        ),
    },
    'install_requires': (
        'beautifulsoup4>=4.6.0',
        'django-anymail>=6.0',
        'django>=2.2.12',
        'html5lib>=1.1',
        'mitol-django-common~=2.0.0',
        'premailer>=3.7.0',
        'toolz>=0.10.0',
    ),
})
